@@ -120,7 +120,39 @@ def bach_patches(
     )
     return ds
 
+""" TODO: how the offline dataset was generated
+from torchvision import transforms
 
+transform = transforms.Compose([
+    transforms.ToPILImage(),
+    transforms.Resize(423), # (2*299**2)**0.5 => 423
+    transforms.ToTensor(),
+])
+
+# BACH
+from histodata.datasets import bach
+
+path_bach = '/data/ldap/histopathologic/original_read_only/BACH/ICIAR2018_BACH_Challenge'
+
+ds = bach.bach_patches(path_bach,
+                       transformation=transform,
+                       subset='train',
+                       seed=200,
+                      )
+ds.save('/data/ldap/histopathologic/original_read_only/BACH2/train')
+ds = bach.bach_patches(path_bach,
+                       transformation=transform,
+                       subset='valid',
+                       seed=200,
+                      )
+ds.save('/data/ldap/histopathologic/original_read_only/BACH2/valid')
+ds = bach.bach_patches(path_bach,
+                       transformation=transform,
+                       subset='test',
+                       seed=200,
+                      )
+ds.save('/data/ldap/histopathologic/original_read_only/BACH2/test')
+"""
 def bach_patches_preprocessed(
     root: str,  # '/data/ldap/histopathologic/original_read_only/BACH2/'
     transformation: O[U[Callable, Sequence[Callable]]] = None,
